==> _private_core_network-1.2.69.tar.gz: lib/network_resources/model/payment_data.dart <==
enum PaymentBuyType { videocall, ticket, purchase }

class PaymentDataModel {
  late String proUniqueId;
  late int commissionId;
  late double price;
  late String pictureUrl;
  late String currency;
  late String title;
  late String key;
  late String merchantName;
  late String description;
  late int id;
  late int datetimeStart;
  late int realStart;
  late int realStop;
  late int cancelTimeUpTo;
  late int callDuration;

  PaymentDataModel(
      {required this.proUniqueId,
      required this.commissionId,
      required this.price,
      required this.pictureUrl,
      required this.currency,
      required this.title,
      required this.key,
      required this.merchantName,
      required this.description,
      required this.id,
      required this.datetimeStart,
      required this.realStart,
      required this.realStop,
      required this.cancelTimeUpTo,
      required this.callDuration});

  PaymentDataModel.fromJson(Map<String, dynamic> json) {
    proUniqueId = json['proUniqueId'] ?? 'PPRRTX4KC';
    commissionId = json['commissionId'] ?? 1;
    price = double.tryParse('${json['price']}') ?? 0;
    pictureUrl = json['pictureUrl'] ?? json['proThumbnail'] ?? '';
    currency = json['currency'] ?? '';
    title = json['title'] ?? json['proDisplayName'] ?? '';
    key = json['key'] ?? '';
    merchantName = json['merchantName'] ?? '';
    description = json['description'] ?? '';
    id = json['id'] ?? 0;
    datetimeStart = json['datetimeStart'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    realStart = json['realStart'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    realStop = json['realStop'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    cancelTimeUpTo = json['cancelTimeUpTo'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    callDuration = json['callDuration'] ?? 0;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['proUniqueId'] = this.proUniqueId;
    data['commissionId'] = this.commissionId;
    data['price'] = this.price;
    data['pictureUrl'] = this.pictureUrl;
    data['currency'] = this.currency;
    data['title'] = this.title;
    data['key'] = this.key;
    data['merchantName'] = this.merchantName;
    data['description'] = this.description;
    data['cancelTimeUpTo'] = this.cancelTimeUpTo;
    data['callDuration'] = this.callDuration;
    return data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/payment_data.dart <==
enum PaymentBuyType { videocall, ticket, purchase }

class PaymentDataModel {
  late String proUniqueId;
  late int commissionId;
  late double price;
  late String pictureUrl;
  late String currency;
  late String title;
  late String key;
  late String merchantName;
  late String description;
  late int id;
  late int datetimeStart;
  late int realStart;
  late int realStop;
  late int cancelTimeUpTo;
  late int callDuration;

  PaymentDataModel(
      {required this.proUniqueId,
      required this.commissionId,
      required this.price,
      required this.pictureUrl,
      required this.currency,
      required this.title,
      required this.key,
      required this.merchantName,
      required this.description,
      required this.id,
      required this.datetimeStart,
      required this.realStart,
      required this.realStop,
      required this.cancelTimeUpTo,
      required this.callDuration});

  PaymentDataModel.fromJson(Map<String, dynamic> json) {
    proUniqueId = json['proUniqueId'] ?? 'PPRRTX4KC';
    commissionId = json['commissionId'] ?? 1;
    price = double.tryParse('${json['price']}') ?? 0;
    pictureUrl = json['pictureUrl'] ?? json['proThumbnail'] ?? '';
    currency = json['currency'] ?? '';
    title = json['title'] ?? json['proDisplayName'] ?? '';
    key = json['key'] ?? '';
    merchantName = json['merchantName'] ?? '';
    description = json['description'] ?? '';
    id = json['id'] ?? 0;
    datetimeStart = json['datetimeStart'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    realStart = json['realStart'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    realStop = json['realStop'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    cancelTimeUpTo = json['cancelTimeUpTo'] ?? DateTime.now().millisecondsSinceEpoch ~/ 1000;
    callDuration = json['callDuration'] ?? 0;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['proUniqueId'] = proUniqueId;
    data['commissionId'] = commissionId;
    data['price'] = price;
    data['pictureUrl'] = pictureUrl;
    data['currency'] = currency;
    data['title'] = title;
    data['key'] = key;
    data['merchantName'] = merchantName;
    data['description'] = description;
    data['cancelTimeUpTo'] = cancelTimeUpTo;
    data['callDuration'] = callDuration;
    return data;
  }
}
